import pathlib

import setuptools

_REPO_URL = "https://git.hammerle.me/fphammerle/intertechno-cc1101-mqtt"

setuptools.setup(
    name="intertechno-cc1101-mqtt",
    use_scm_version={
        # > AssertionError: cant parse version docker/0.1.0-amd64
        # https://github.com/pypa/setuptools_scm/blob/master/src/setuptools_scm/git.py#L15
        "git_describe_command": "git describe --dirty --tags --long --match v*"
    },
    packages=setuptools.find_packages(),
    description="MQTT client controlling Intertechno smart outlets via CC1101 transceiver, "
    # https://www.home-assistant.io/integrations/switch.mqtt/
    "compatible with home-assistant.io's MQTT Switch platform",
    long_description=pathlib.Path(__file__).parent.joinpath("README.md").read_text(),
    long_description_content_type="text/markdown",
    author="Fabian Peter Hammerle",
    author_email="fabian@hammerle.me",
    url=_REPO_URL,
    project_urls={"Changelog": _REPO_URL + "/blob/master/CHANGELOG.md"},
    keywords=[
        "automation",
        "home-assistant.io",
        "home-automation",
        "intertechno",
        "mqtt",
        "outlet",
        "power",
        "radio-frequency",
        "raspberry-pi",
        "remote-control",
        "switch",
    ],
    classifiers=[
        # https://pypi.org/classifiers/
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: End Users/Desktop",
        "Intended Audience :: System Administrators",
        "Operating System :: POSIX :: Linux",
        "Topic :: Home Automation",
    ],
    # entry_points={"console_scripts": ["intertechno-cc1101-mqtt = intertechno_cc1101:_main"]},
    install_requires=["intertechno-cc1101>=0.1.0,<0.2", "paho-mqtt<2"],
    setup_requires=["setuptools_scm"],
    tests_require=["pytest"],
    dependency_links=[
        "git+https://git.hammerle.me/fphammerle/intertechno-cc1101@v0.1.0"
        "#egg=intertechno-cc1101-0.1.0"
    ],
)
